@@ -26,8 +26,8 @@ class MemmappingExecutor(_ReusablePoolExecutor):
     def get_memmapping_executor(cls, n_jobs, timeout=300, initializer=None,
                                 initargs=(), env=None, temp_folder=None,
                                 context_id=None, **backend_args):
-        """Factory for ReusableExecutor with automatic memmapping for large numpy
-        arrays.
+        """Factory for ReusableExecutor with automatic memmapping for large
+        numpy arrays.
         """
         global _executor_args
         # Check if we can reuse the executor here instead of deferring the test
@@ -71,25 +71,22 @@ class MemmappingExecutor(_ReusablePoolExecutor):
         return _executor
 
     def terminate(self, kill_workers=False):
-        self.shutdown(kill_workers=kill_workers)
-        if kill_workers:
-            # When workers are killed in such a brutal manner, they cannot
-            # execute the finalizer of their shared memmaps. The refcount of
-            # those memmaps may be off by an unknown number, so instead of
-            # decref'ing them, we delete the whole temporary folder, and
-            # unregister them. There is no risk of PermissionError at folder
-            # deletion because because at this point, all child processes are
-            # dead, so all references to temporary memmaps are closed.
 
-            # unregister temporary resources from all contexts
-            with self._submit_resize_lock:
-                self._temp_folder_manager._unregister_temporary_resources()
-                self._temp_folder_manager._try_delete_folder(
-                    allow_non_empty=True
-                )
-        else:
-            self._temp_folder_manager._unlink_temporary_resources()
-            self._temp_folder_manager._try_delete_folder(allow_non_empty=True)
+        self.shutdown(kill_workers=kill_workers)
+
+        # When workers are killed in a brutal manner, they cannot execute the
+        # finalizer of their shared memmaps. The refcount of those memmaps may
+        # be off by an unknown number, so instead of decref'ing them, we force
+        # delete the whole temporary folder, and unregister them. There is no
+        # risk of PermissionError at folder deletion because at this
+        # point, all child processes are dead, so all references to temporary
+        # memmaps are closed. Otherwise, just try to delete as much as possible
+        # with allow_non_empty=True but if we can't, it will be clean up later
+        # on by the resource_tracker.
+        with self._submit_resize_lock:
+            self._temp_folder_manager._clean_temporary_resources(
+                force=kill_workers, allow_non_empty=True
+            )
 
     @property
     def _temp_folder(self):
